//---------------------------------------------------------------------------

#include <vcl.h>
#pragma hdrstop

#include "Global2.h"
#include "QSProxyWins.h"
#include "PrxyOptionsDlgs.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
#pragma resource "*.dfm"
TPrxyOptionsDlg *PrxyOptionsDlg;
//---------------------------------------------------------------------------

bool __fastcall OpenProxyOptionsDialog(TQSProxyWin *Owner, const AnsiString &Title)
{
   PrxyOptionsDlg = new TPrxyOptionsDlg(Owner, Title);
   PrxyOptionsDlg->Font->Assign(Owner->Font);
   PrxyOptionsDlg->ShowModal();
   if (PrxyOptionsDlg->ModalResult == mrOk)
   {
      Owner->DetailFrame->Color = PrxyOptionsDlg->WorkColor->Color;
      StrToFont(PrxyOptionsDlg->WinsFontStr, Owner->DetailFrame->Font);
      StrToFont(PrxyOptionsDlg->DlgsFontStr, Owner->Font);
   }
   bool ok = PrxyOptionsDlg->ModalResult == mrOk;
   delete PrxyOptionsDlg;
   return ok;
}

//---------------------------------------------------------------------------
// TPrxyOptionsDlg
//---------------------------------------------------------------------------

__fastcall TPrxyOptionsDlg::TPrxyOptionsDlg(TComponent* Owner)
   : TForm(Owner)
{
}
//---------------------------------------------------------------------------

__fastcall TPrxyOptionsDlg::TPrxyOptionsDlg(TComponent* Owner, const AnsiString &Title)
   : TForm(Owner)
{
   Caption = Title;
   IniModified = false;
   PageControl->ActivePage = GenTab;

   TIniFile *ini = new TIniFile(AppIni());

   WorkColor->Color = (TColor)ini->ReadInteger(ProxyIni, QSWINDOWCOLOR, QSWINDOWCOLORDEF);
   WinsFontStr = ini->ReadString(ProxyIni, QSWINDOWFONT, QSWINDOWFONTDEF);
   DlgsFontStr = ini->ReadString(ProxyIni, QSDIALOGFONT, QSDIALOGFONTDEF);
   EditFontStr = ini->ReadString(ProxyIni, QSEDITORFONT, QSEDITORFONTDEF);

   StrToFontBox(WinsFontStr, Name1, Size1, Style1, Color1);
   StrToFontBox(DlgsFontStr, Name2, Size2, Style2, Color2);
   StrToFontBox(EditFontStr, Name6, Size6, Style6, Color6);

   delete ini;
}
//---------------------------------------------------------------------------

__fastcall TPrxyOptionsDlg::~TPrxyOptionsDlg()
{
}
//---------------------------------------------------------------------------
#pragma argsused
void __fastcall TPrxyOptionsDlg::FormCloseQuery(TObject *Sender,
      bool &CanClose)
{
   if (IniModified)
   {
      if (ModalResult == mrCancel)
      {
         switch (MsgBox(this, "Your options are modified. Save your changes?",
            MT_CONFIRM, MB_YESNOCANCEL))
         {
            case IDCANCEL: CanClose = false;
            case IDNO: return;
         }
      }

      ModalResult = mrOk;
      TIniFile *ini = new TIniFile(AppIni());

      ini->WriteInteger(ProxyIni, QSWINDOWCOLOR, WorkColor->Color);
      ini->WriteString(ProxyIni, QSWINDOWFONT, WinsFontStr);
      ini->WriteString(ProxyIni, QSDIALOGFONT, DlgsFontStr);
      ini->WriteString(ProxyIni, QSEDITORFONT, EditFontStr);

      delete ini;
   }
}

//---------------------------------------------------------------------------
// General
//---------------------------------------------------------------------------

void __fastcall TPrxyOptionsDlg::WorkColorBtnClick(TObject *)
{
   ColorDialog->Color = WorkColor->Color;
   if (ColorDialog->Execute())
   {
      TColor color = ColorDialog->Color;
      WorkColor->Color = color;

      IniModified = true;
   }
}
//---------------------------------------------------------------------------

void __fastcall TPrxyOptionsDlg::StrToFontBox(const AnsiString &FontStr, TEdit *Name,
   TEdit *Size, TEdit *Style, TPanel *Color)
{
   Name->Text  = GetTok(0, FontStr, ',');
   Size->Text  = GetTok(1, FontStr, ',');
   Style->Text = GetTok(2, FontStr, ',');
   Color->Color = (TColor)GetTok(3, FontStr, ',').ToIntDef(0);
}
//---------------------------------------------------------------------------

void __fastcall TPrxyOptionsDlg::StrToFont(const AnsiString &FontStr, TFont *Font)
{
   Font->Name = GetTok(0, FontStr, ',');
   Font->Size = GetTok(1, FontStr, ',').ToIntDef(8);

   Font->Style.Clear();
   AnsiString stylestr = GetTok(2, FontStr, ',').LowerCase();
   if (stylestr.Pos("b") > 0) Font->Style << fsBold;
   if (stylestr.Pos("i") > 0) Font->Style << fsItalic;
   if (stylestr.Pos("u") > 0) Font->Style << fsUnderline;
   if (stylestr.Pos("s") > 0) Font->Style << fsStrikeOut;

   Font->Color = (TColor)GetTok(3, FontStr, ',').ToIntDef(0);
}
//---------------------------------------------------------------------------

AnsiString __fastcall TPrxyOptionsDlg::FontToStr(TFont *Font)
{
   AnsiString fontstr = Font->Name;
   fontstr += "," + IntToStr(Font->Size);

   fontstr += ",";
   if (Font->Style.Contains(fsBold)) fontstr += "b";
   if (Font->Style.Contains(fsItalic)) fontstr += "i";
   if (Font->Style.Contains(fsUnderline)) fontstr += "u";
   if (Font->Style.Contains(fsStrikeOut)) fontstr += "s";

   fontstr += "," + IntToStr(Font->Color);
   return fontstr;
}
//---------------------------------------------------------------------------

void __fastcall TPrxyOptionsDlg::WinFontBtnClick(TObject *)
{
   StrToFont(WinsFontStr, FontDialog->Font);
   if (FontDialog->Execute())
   {
      WinsFontStr = FontToStr(FontDialog->Font);
      StrToFontBox(WinsFontStr, Name1, Size1, Style1, Color1);

      IniModified = true;
   }
}
//---------------------------------------------------------------------------

void __fastcall TPrxyOptionsDlg::DlgFontBtnClick(TObject *)
{
   StrToFont(DlgsFontStr, FontDialog->Font);
   if (FontDialog->Execute())
   {
      DlgsFontStr = FontToStr(FontDialog->Font);
      StrToFontBox(DlgsFontStr, Name2, Size2, Style2, Color2);
      Font->Assign(FontDialog->Font);

      IniModified = true;
   }
}
//---------------------------------------------------------------------------

